@@ -4,9 +4,11 @@
 #include <pybind11/stl.h>
 #include <unicode/numberformatter.h>
 
-#if (U_ICU_VERSION_MAJOR_NUM >= 71)
+#if (U_ICU_VERSION_MAJOR_NUM == 71)
 #include <unicode/unounclass.h>
-#endif // (U_ICU_VERSION_MAJOR_NUM >= 71)
+#elif (U_ICU_VERSION_MAJOR_NUM >= 72)
+#include <unicode/displayoptions.h>
+#endif // (U_ICU_VERSION_MAJOR_NUM == 71)
 
 using namespace icu;
 using namespace icu::number;
@@ -345,6 +347,15 @@ void init_numberformatter(py::module &, py::module &m2) {
       },
       py::arg("style"));
 
+#if (U_ICU_VERSION_MAJOR_NUM >= 72)
+  nfs_lnf.def(
+      "display_options",
+      [](const _LocalizedNumberFormatterSettings &self, const DisplayOptions &display_options) {
+        return self.displayOptions(display_options);
+      },
+      py::arg("display_options"));
+#endif // (U_ICU_VERSION_MAJOR_NUM >= 72)
+
 #if (U_ICU_VERSION_MAJOR_NUM >= 61)
   nfs_lnf.def(
       "grouping",
@@ -462,6 +473,15 @@ void init_numberformatter(py::module &, py::module &m2) {
       },
       py::arg("style"));
 
+#if (U_ICU_VERSION_MAJOR_NUM >= 72)
+  nfs_unf.def(
+      "display_options",
+      [](const _UnlocalizedNumberFormatterSettings &self, const DisplayOptions &display_options) {
+        return self.displayOptions(display_options);
+      },
+      py::arg("display_options"));
+#endif // (U_ICU_VERSION_MAJOR_NUM >= 72)
+
 #if (U_ICU_VERSION_MAJOR_NUM >= 61)
   nfs_unf.def(
       "grouping",
@@ -576,7 +596,7 @@ void init_numberformatter(py::module &, py::module &m2) {
   pre.def_static("increment", &Precision::increment, py::arg("rounding_increment"));
 
 #if (U_ICU_VERSION_MAJOR_NUM >= 71)
-  pre.def_static("increment_exact", Precision::incrementExact, py::arg("mantissa"), py::arg("magnitude"));
+  pre.def_static("increment_exact", &Precision::incrementExact, py::arg("mantissa"), py::arg("magnitude"));
 #endif // (U_ICU_VERSION_MAJOR_NUM >= 71)
 
   pre.def_static("integer", &Precision::integer);
