@@ -180,7 +180,7 @@ void init_ubidi(py::module &m) {
         ErrorCode error_code;
         auto result = ubidi_countRuns(bidi, error_code);
         if (error_code.isFailure()) {
-          throw ICUError(error_code);
+          throw icupy::ICUError(error_code);
         }
         return result;
       },
@@ -225,7 +225,7 @@ void init_ubidi(py::module &m) {
         ErrorCode error_code;
         auto p = ubidi_getLevels(bidi, error_code);
         if (error_code.isFailure()) {
-          throw ICUError(error_code);
+          throw icupy::ICUError(error_code);
         }
         const auto length = ubidi_getProcessedLength(bidi);
         std::vector<UBiDiLevel> result(p, p + length);
@@ -239,7 +239,7 @@ void init_ubidi(py::module &m) {
         ErrorCode error_code;
         auto result = ubidi_getLogicalIndex(bidi, visual_index, error_code);
         if (error_code.isFailure()) {
-          throw ICUError(error_code);
+          throw icupy::ICUError(error_code);
         }
         return result;
       },
@@ -255,7 +255,7 @@ void init_ubidi(py::module &m) {
         std::vector<int32_t> result(length);
         ubidi_getLogicalMap(bidi, result.data(), error_code);
         if (error_code.isFailure()) {
-          throw ICUError(error_code);
+          throw icupy::ICUError(error_code);
         }
         return result;
       },
@@ -280,7 +280,7 @@ void init_ubidi(py::module &m) {
         UBiDiLevel para_level;
         auto result = ubidi_getParagraph(bidi, char_index, &para_start, &para_limit, &para_level, error_code);
         if (error_code.isFailure()) {
-          throw ICUError(error_code);
+          throw icupy::ICUError(error_code);
         }
         return py::make_tuple(result, para_start, para_limit, para_level);
       },
@@ -295,7 +295,7 @@ void init_ubidi(py::module &m) {
         UBiDiLevel para_level;
         ubidi_getParagraphByIndex(bidi, para_index, &para_start, &para_limit, &para_level, error_code);
         if (error_code.isFailure()) {
-          throw ICUError(error_code);
+          throw icupy::ICUError(error_code);
         }
         return py::make_tuple(para_start, para_limit, para_level);
       },
@@ -327,7 +327,7 @@ void init_ubidi(py::module &m) {
         ErrorCode error_code;
         auto result = ubidi_getVisualIndex(bidi, logical_index, error_code);
         if (error_code.isFailure()) {
-          throw ICUError(error_code);
+          throw icupy::ICUError(error_code);
         }
         return result;
       },
@@ -343,7 +343,7 @@ void init_ubidi(py::module &m) {
         std::vector<int32_t> result(length);
         ubidi_getVisualMap(bidi, result.data(), error_code);
         if (error_code.isFailure()) {
-          throw ICUError(error_code);
+          throw icupy::ICUError(error_code);
         }
         return result;
       },
@@ -386,7 +386,7 @@ void init_ubidi(py::module &m) {
         ErrorCode error_code;
         auto bidi = ubidi_openSized(max_length, max_run_count, error_code);
         if (error_code.isFailure()) {
-          throw ICUError(error_code);
+          throw icupy::ICUError(error_code);
         }
         return std::make_unique<_UBiDiPtr>(bidi);
       },
@@ -435,7 +435,7 @@ void init_ubidi(py::module &m) {
         ErrorCode error_code;
         ubidi_setClassCallback(bidi, fp, cp, &old_fn, &old_context, error_code);
         if (error_code.isFailure()) {
-          throw ICUError(error_code);
+          throw icupy::ICUError(error_code);
         }
         if (old_fn == new_fn.callback) {
           // Old Python callback function and old callback data
@@ -471,7 +471,7 @@ void init_ubidi(py::module &m) {
         }
         ubidi_setContext(bidi, prologue_ptr.get(), pro_length, epilogue_ptr.get(), epi_length, error_code);
         if (error_code.isFailure()) {
-          throw ICUError(error_code);
+          throw icupy::ICUError(error_code);
         }
         bidi.set_prologue(prologue_ptr);
         bidi.set_epilogue(epilogue_ptr);
@@ -488,7 +488,7 @@ void init_ubidi(py::module &m) {
         ErrorCode error_code;
         ubidi_setLine(para_bidi, start, limit, line_bidi, error_code);
         if (error_code.isFailure()) {
-          throw ICUError(error_code);
+          throw icupy::ICUError(error_code);
         }
       },
       py::arg("para_bidi"), py::arg("start"), py::arg("limit"), py::arg("line_bidi"));
@@ -513,7 +513,7 @@ void init_ubidi(py::module &m) {
         }
         ubidi_setPara(bidi, text_ptr.get(), length, para_level, embedding_levels_ptr.get(), error_code);
         if (error_code.isFailure()) {
-          throw ICUError(error_code);
+          throw icupy::ICUError(error_code);
         }
         bidi.set_text(text_ptr);
         bidi.set_embedding_levels(embedding_levels_ptr);
@@ -547,7 +547,7 @@ void init_ubidi(py::module &m) {
         std::u16string result(length, u'\0');
         length = ubidi_writeReordered(bidi, result.data(), static_cast<int32_t>(result.size()), options, error_code);
         if (error_code.isFailure()) {
-          throw ICUError(error_code);
+          throw icupy::ICUError(error_code);
         }
         result.resize(length);
         return result;
@@ -562,7 +562,7 @@ void init_ubidi(py::module &m) {
         const auto length = ubidi_writeReverse(src, src_length, result.data(), static_cast<int32_t>(result.size()),
                                                options, error_code);
         if (error_code.isFailure()) {
-          throw ICUError(error_code);
+          throw icupy::ICUError(error_code);
         }
         result.resize(length);
         return result;
