@@ -387,6 +387,15 @@ void init_uchar(py::module &m) {
       .value("UBLOCK_VITHKUQI", UBLOCK_VITHKUQI)
       .value("UBLOCK_ZNAMENNY_MUSICAL_NOTATION", UBLOCK_ZNAMENNY_MUSICAL_NOTATION)
 #endif // (U_ICU_VERSION_MAJOR_NUM >= 70)
+#if (U_ICU_VERSION_MAJOR_NUM >= 72)
+      .value("UBLOCK_ARABIC_EXTENDED_C", UBLOCK_ARABIC_EXTENDED_C)
+      .value("UBLOCK_CJK_UNIFIED_IDEOGRAPHS_EXTENSION_H", UBLOCK_CJK_UNIFIED_IDEOGRAPHS_EXTENSION_H)
+      .value("UBLOCK_CYRILLIC_EXTENDED_D", UBLOCK_CYRILLIC_EXTENDED_D)
+      .value("UBLOCK_DEVANAGARI_EXTENDED_A", UBLOCK_DEVANAGARI_EXTENDED_A)
+      .value("UBLOCK_KAKTOVIK_NUMERALS", UBLOCK_KAKTOVIK_NUMERALS)
+      .value("UBLOCK_KAWI", UBLOCK_KAWI)
+      .value("UBLOCK_NAG_MUNDARI", UBLOCK_NAG_MUNDARI)
+#endif // (U_ICU_VERSION_MAJOR_NUM >= 72)
 #ifndef U_HIDE_DEPRECATED_API
       .value("UBLOCK_COUNT", UBLOCK_COUNT,
              "**Deprecated:** ICU 58 The numeric value may change over time, see ICU ticket #12420.")
