@@ -1,4 +1,5 @@
 import pytest
+
 from icupy.icu import U_ICU_VERSION_MAJOR_NUM
 
 if U_ICU_VERSION_MAJOR_NUM < 63:
@@ -6,23 +7,30 @@ if U_ICU_VERSION_MAJOR_NUM < 63:
 
 import copy
 
+# fmt: off
 from icupy.icu import (
-    ErrorCode, Formattable, Locale, MeasureUnit, UErrorCode,
-    UNumberRangeCollapse, UNumberRangeIdentityFallback,
-    UNumberRangeIdentityResult, UnicodeString, UnicodeStringAppendable,
+    ErrorCode, Formattable, Locale, MeasureUnit, UErrorCode, UnicodeString,
+    UnicodeStringAppendable, UNumberRangeCollapse,
+    UNumberRangeIdentityFallback, UNumberRangeIdentityResult,
 )
 from icupy.icu.number import (
     FormattedNumberRange, LocalizedNumberRangeFormatter, NumberFormatter,
     NumberRangeFormatter, UnlocalizedNumberRangeFormatter,
 )
 
+# fmt: on
+
 
 def test_formatted_number_range_63():
-    fmt = (NumberRangeFormatter.with_locale("en-US")
-           .number_formatter_first(NumberFormatter.with_()
-                                   .unit(MeasureUnit.create_meter()))
-           .number_formatter_second(NumberFormatter.with_()
-                                    .unit(MeasureUnit.create_kilometer())))
+    fmt = (
+        NumberRangeFormatter.with_locale("en-US")
+        .number_formatter_first(
+            NumberFormatter.with_().unit(MeasureUnit.create_meter())
+        )
+        .number_formatter_second(
+            NumberFormatter.with_().unit(MeasureUnit.create_kilometer())
+        )
+    )
     assert isinstance(fmt, LocalizedNumberRangeFormatter)
 
     num = fmt.format_formattable_range(Formattable(3), Formattable(3000))
@@ -41,8 +49,10 @@ def test_formatted_number_range_63():
 
     # UNumberRangeIdentityResult
     # icu::number::FormattedNumberRange::getIdentityResult(UErrorCode &status)
-    assert (num.get_identity_result()
-            == UNumberRangeIdentityResult.UNUM_IDENTITY_RESULT_NOT_EQUAL)
+    assert (
+        num.get_identity_result()
+        == UNumberRangeIdentityResult.UNUM_IDENTITY_RESULT_NOT_EQUAL
+    )
 
     # UnicodeString icu::number::FormattedNumberRange::toString(
     #       UErrorCode &status
@@ -58,11 +68,15 @@ def test_formatted_number_range_64():
 
     assert issubclass(FormattedNumberRange, FormattedValue)
 
-    fmt = (NumberRangeFormatter.with_locale("en-US")
-           .number_formatter_first(NumberFormatter.with_()
-                                   .unit(MeasureUnit.create_meter()))
-           .number_formatter_second(NumberFormatter.with_()
-                                    .unit(MeasureUnit.create_kilometer())))
+    fmt = (
+        NumberRangeFormatter.with_locale("en-US")
+        .number_formatter_first(
+            NumberFormatter.with_().unit(MeasureUnit.create_meter())
+        )
+        .number_formatter_second(
+            NumberFormatter.with_().unit(MeasureUnit.create_kilometer())
+        )
+    )
     assert isinstance(fmt, LocalizedNumberRangeFormatter)
 
     num = fmt.format_formattable_range(Formattable(3), Formattable(3000))
@@ -78,11 +92,15 @@ def test_formatted_number_range_64():
 
 @pytest.mark.skipif(U_ICU_VERSION_MAJOR_NUM < 68, reason="ICU4C<68")
 def test_formatted_number_range_68():
-    fmt = (NumberRangeFormatter.with_locale("en-US")
-           .number_formatter_first(NumberFormatter.with_()
-                                   .unit(MeasureUnit.create_meter()))
-           .number_formatter_second(NumberFormatter.with_()
-                                    .unit(MeasureUnit.create_kilometer())))
+    fmt = (
+        NumberRangeFormatter.with_locale("en-US")
+        .number_formatter_first(
+            NumberFormatter.with_().unit(MeasureUnit.create_meter())
+        )
+        .number_formatter_second(
+            NumberFormatter.with_().unit(MeasureUnit.create_kilometer())
+        )
+    )
     assert isinstance(fmt, LocalizedNumberRangeFormatter)
 
     num = fmt.format_formattable_range(Formattable(3), Formattable(3000))
@@ -101,15 +119,22 @@ def test_formatted_number_range_68():
 
 @pytest.mark.skipif(U_ICU_VERSION_MAJOR_NUM < 69, reason="ICU4C<69")
 def test_formatted_number_range_69():
+    # fmt: off
     from icupy.icu import (
         ConstrainedFieldPosition, UFieldCategory, UNumberFormatFields,
     )
 
-    fmt = (NumberRangeFormatter.with_locale("en-US")
-           .number_formatter_first(NumberFormatter.with_()
-                                   .unit(MeasureUnit.create_meter()))
-           .number_formatter_second(NumberFormatter.with_()
-                                    .unit(MeasureUnit.create_kilometer())))
+    # fmt: on
+
+    fmt = (
+        NumberRangeFormatter.with_locale("en-US")
+        .number_formatter_first(
+            NumberFormatter.with_().unit(MeasureUnit.create_meter())
+        )
+        .number_formatter_second(
+            NumberFormatter.with_().unit(MeasureUnit.create_kilometer())
+        )
+    )
     assert isinstance(fmt, LocalizedNumberRangeFormatter)
 
     # "3 m – 3,000 km"
@@ -122,8 +147,10 @@ def test_formatted_number_range_69():
     # )
     cfpos = ConstrainedFieldPosition()
     assert num.next_position(cfpos)
-    assert (cfpos.get_category()
-            == UFieldCategory.UFIELD_CATEGORY_NUMBER_RANGE_SPAN)
+    assert (
+        cfpos.get_category()
+        == UFieldCategory.UFIELD_CATEGORY_NUMBER_RANGE_SPAN
+    )
     assert cfpos.get_field() == UNumberFormatFields.UNUM_INTEGER_FIELD
     assert (cfpos.get_start(), cfpos.get_limit()) == (0, 3)  # "3 m"
 
@@ -138,15 +165,18 @@ def test_formatted_number_range_69():
     assert (cfpos.get_start(), cfpos.get_limit()) == (2, 3)  # "m"
 
     assert num.next_position(cfpos)
-    assert (cfpos.get_category()
-            == UFieldCategory.UFIELD_CATEGORY_NUMBER_RANGE_SPAN)
+    assert (
+        cfpos.get_category()
+        == UFieldCategory.UFIELD_CATEGORY_NUMBER_RANGE_SPAN
+    )
     assert cfpos.get_field() == UNumberFormatFields.UNUM_FRACTION_FIELD
     assert (cfpos.get_start(), cfpos.get_limit()) == (6, 14)  # "3,000 km"
 
     assert num.next_position(cfpos)
     assert cfpos.get_category() == UFieldCategory.UFIELD_CATEGORY_NUMBER
-    assert (cfpos.get_field()
-            == UNumberFormatFields.UNUM_GROUPING_SEPARATOR_FIELD)
+    assert (
+        cfpos.get_field() == UNumberFormatFields.UNUM_GROUPING_SEPARATOR_FIELD
+    )
     assert (cfpos.get_start(), cfpos.get_limit()) == (7, 8)  # ","
 
     assert num.next_position(cfpos)
@@ -193,7 +223,8 @@ def test_localized_number_range_formatter_63():
     #       UNumberRangeIdentityFallback identityFallback
     # )
     result = fmt2.identity_fallback(
-        UNumberRangeIdentityFallback.UNUM_IDENTITY_FALLBACK_RANGE)
+        UNumberRangeIdentityFallback.UNUM_IDENTITY_FALLBACK_RANGE
+    )
     assert isinstance(result, LocalizedNumberRangeFormatter)
 
     # [2]
@@ -227,36 +258,51 @@ def test_localized_number_range_formatter_63():
     #       UErrorCode &status
     # )
     formatter = NumberFormatter.with_().unit(MeasureUnit.create_kilometer())
-    result = (fmt2.number_formatter_both(formatter)
-              .format_formattable_range(Formattable(4), Formattable(6)))
+    result = fmt2.number_formatter_both(formatter).format_formattable_range(
+        Formattable(4), Formattable(6)
+    )
     assert isinstance(result, FormattedNumberRange)
 
 
 @pytest.mark.skipif(U_ICU_VERSION_MAJOR_NUM < 64, reason="ICU4C<64")
 def test_localized_number_range_formatter_64():
     formatter = NumberFormatter.with_().unit(MeasureUnit.create_meter())
-    fmt = (NumberRangeFormatter.with_locale("en-US")
-           .collapse(UNumberRangeCollapse.UNUM_RANGE_COLLAPSE_NONE)
-           .number_formatter_both(formatter))
+    fmt = (
+        NumberRangeFormatter.with_locale("en-US")
+        .collapse(UNumberRangeCollapse.UNUM_RANGE_COLLAPSE_NONE)
+        .number_formatter_both(formatter)
+    )
     assert isinstance(fmt, LocalizedNumberRangeFormatter)
-    assert (fmt.format_formattable_range(Formattable(1), Formattable(5))
-            .to_string()) == "1 m \u2013 5 m"  # 1 m - 5 m
+    assert (
+        fmt.format_formattable_range(
+            Formattable(1), Formattable(5)
+        ).to_string()
+    ) == "1 m \u2013 5 m"  # 1 m - 5 m
 
     # template<typename Derived>
     # LocalPointer<Derived>
     # icu::number::NumberRangeFormatterSettings<Derived>::clone()
     fmt2 = fmt.clone()
     assert isinstance(fmt2, LocalizedNumberRangeFormatter)
-    assert (fmt2.format_formattable_range(Formattable(1), Formattable(5))
-            .to_string()) == "1 m \u2013 5 m"  # 1 m - 5 m
+    assert (
+        fmt2.format_formattable_range(
+            Formattable(1), Formattable(5)
+        ).to_string()
+    ) == "1 m \u2013 5 m"  # 1 m - 5 m
 
     fmt3 = copy.copy(fmt)
-    assert (fmt3.format_formattable_range(Formattable(1), Formattable(5))
-            .to_string()) == "1 m \u2013 5 m"  # 1 m - 5 m
+    assert (
+        fmt3.format_formattable_range(
+            Formattable(1), Formattable(5)
+        ).to_string()
+    ) == "1 m \u2013 5 m"  # 1 m - 5 m
 
     fmt4 = copy.deepcopy(fmt)
-    assert (fmt4.format_formattable_range(Formattable(1), Formattable(5))
-            .to_string()) == "1 m \u2013 5 m"  # 1 m - 5 m
+    assert (
+        fmt4.format_formattable_range(
+            Formattable(1), Formattable(5)
+        ).to_string()
+    ) == "1 m \u2013 5 m"  # 1 m - 5 m
 
 
 def test_number_range_formatter():
@@ -315,7 +361,8 @@ def test_unlocalized_number_range_formatter_63():
     #       UNumberRangeIdentityFallback identityFallback
     # )
     result = fmt2.identity_fallback(
-        UNumberRangeIdentityFallback.UNUM_IDENTITY_FALLBACK_RANGE)
+        UNumberRangeIdentityFallback.UNUM_IDENTITY_FALLBACK_RANGE
+    )
     assert isinstance(result, UnlocalizedNumberRangeFormatter)
 
     # [2]
@@ -346,29 +393,39 @@ def test_unlocalized_number_range_formatter_63():
 @pytest.mark.skipif(U_ICU_VERSION_MAJOR_NUM < 64, reason="ICU4C<64")
 def test_unlocalized_number_range_formatter_64():
     formatter = NumberFormatter.with_().unit(MeasureUnit.create_meter())
-    fmt = (NumberRangeFormatter.with_()
-           .collapse(UNumberRangeCollapse.UNUM_RANGE_COLLAPSE_NONE)
-           .number_formatter_both(formatter))
+    fmt = (
+        NumberRangeFormatter.with_()
+        .collapse(UNumberRangeCollapse.UNUM_RANGE_COLLAPSE_NONE)
+        .number_formatter_both(formatter)
+    )
     assert isinstance(fmt, UnlocalizedNumberRangeFormatter)
-    assert (fmt.locale("en-US")
-            .format_formattable_range(Formattable(1), Formattable(5))
-            .to_string()) == "1 m \u2013 5 m"  # 1 m - 5 m
+    assert (
+        fmt.locale("en-US")
+        .format_formattable_range(Formattable(1), Formattable(5))
+        .to_string()
+    ) == "1 m \u2013 5 m"  # 1 m - 5 m
 
     # template<typename Derived>
     # LocalPointer<Derived>
     # icu::number::NumberRangeFormatterSettings<Derived>::clone()
     fmt2 = fmt.clone()
     assert isinstance(fmt2, UnlocalizedNumberRangeFormatter)
-    assert (fmt2.locale("en-US")
-            .format_formattable_range(Formattable(1), Formattable(5))
-            .to_string()) == "1 m \u2013 5 m"  # 1 m - 5 m
+    assert (
+        fmt2.locale("en-US")
+        .format_formattable_range(Formattable(1), Formattable(5))
+        .to_string()
+    ) == "1 m \u2013 5 m"  # 1 m - 5 m
 
     fmt3 = copy.copy(fmt)
-    assert (fmt3.locale("en-US")
-            .format_formattable_range(Formattable(1), Formattable(5))
-            .to_string()) == "1 m \u2013 5 m"  # 1 m - 5 m
+    assert (
+        fmt3.locale("en-US")
+        .format_formattable_range(Formattable(1), Formattable(5))
+        .to_string()
+    ) == "1 m \u2013 5 m"  # 1 m - 5 m
 
     fmt4 = copy.deepcopy(fmt)
-    assert (fmt4.locale("en-US")
-            .format_formattable_range(Formattable(1), Formattable(5))
-            .to_string()) == "1 m \u2013 5 m"  # 1 m - 5 m
+    assert (
+        fmt4.locale("en-US")
+        .format_formattable_range(Formattable(1), Formattable(5))
+        .to_string()
+    ) == "1 m \u2013 5 m"  # 1 m - 5 m
