@@ -274,15 +274,22 @@ def test_get_bound():
     result2 = Collator.get_bound(
         source, len(source), UColBoundMode.UCOL_BOUND_UPPER, 1
     )
-    assert isinstance(result1, list)
-    assert isinstance(result2, list)
+    assert isinstance(result1, bytes)
+    assert isinstance(result2, bytes)
     assert len(result1) > 0
     assert len(result2) > 0
-    assert all(isinstance(x, int) for x in result1)
-    assert all(isinstance(x, int) for x in result2)
     assert result1 < source
     assert result2 > source
 
+    result1a = Collator.get_bound(
+        source, -1, UColBoundMode.UCOL_BOUND_LOWER, 1
+    )
+    result2a = Collator.get_bound(
+        source, -1, UColBoundMode.UCOL_BOUND_UPPER, 1
+    )
+    assert result1 == result1a
+    assert result2 == result2a
+
 
 def test_get_collation_key():
     coll = Collator.create_instance(Locale.get_english())
@@ -542,9 +549,8 @@ def test_get_sort_key():
     #       int32_t resultLength
     # )
     result1 = coll.get_sort_key("ABC", -1)
-    assert isinstance(result1, list)
+    assert isinstance(result1, bytes)
     assert len(result1) > 0
-    assert all(isinstance(x, int) for x in result1)
 
     # [2]
     # int32_t icu::Collator::getSortKey(
@@ -553,9 +559,8 @@ def test_get_sort_key():
     #       int32_t resultLength
     # )
     result2 = coll.get_sort_key(UnicodeString("abc"))
-    assert isinstance(result2, list)
+    assert isinstance(result2, bytes)
     assert len(result2) > 0
-    assert all(isinstance(x, int) for x in result2)
 
     result2a = coll.get_sort_key("abc")
     assert result2a == result2
@@ -582,7 +587,7 @@ def test_get_version():
 
     # void icu::Collator::getVersion(UVersionInfo info)
     info = coll.get_version()
-    assert isinstance(info, list)
+    assert isinstance(info, tuple)
     assert len(info) == 4
     assert all(isinstance(x, int) for x in info)
     assert info[0] > 0
